import type {
  GalleryEntry,
  GalleryEntryInheritedProperties,
} from '@goldenwere/mackenzii-types'

import { deepCopy } from 'src/utilities/dom'

export const getTitleFromEntryOrId = (entry: GalleryEntry, id: string) => (
  entry.title !== undefined
    ? entry.title === '' || entry.title === null
      ? 'untitled'
      : entry.title
    : id
)

export const amendVariantsWithDefaults = (parent: GalleryEntryInheritedProperties, children: GalleryEntryInheritedProperties) => {
  const _children = deepCopy(children)
  if (!!_children) {
    Object.keys(children).forEach(id => {
      _children[id] = _amendVariantWithDefaults(parent, children[id])
    })
  }

  return _children
}

export const _amendVariantWithDefaults = (parent: GalleryEntryInheritedProperties, variant: GalleryEntryInheritedProperties) => {
  if (variant.title === undefined && (!!parent.title || parent.title === null || parent.title === '')) {
    variant.title = parent.title
  }
  if (!variant.description && !!parent.description) {
    variant.description = parent.description
  }
  if (variant.warning === undefined && !!parent.warning) {
    variant.warning = parent.warning
  }
  if (!variant.fields && !!parent.fields) {
    variant.fields = parent.fields
  }
  if (!variant.tags && !!parent.tags) {
    variant.tags = parent.tags
  }
  if (!variant.thumbnailPosition && !!parent.thumbnailPosition) {
    variant.thumbnailPosition = parent.thumbnailPosition
  }
  if (!variant.thumbnailBackground && !!parent.thumbnailBackground) {
    variant.thumbnailBackground = parent.thumbnailBackground
  }
  if (!variant.background && !!parent.background) {
    variant.background = parent.background
  }

  return variant
}
